@@ -1,14 +1,14 @@
 #' Set variable labels/value labels on variables in the data.frame
 #' 
 #' \code{apply_labels} tries automatically detect what is variable label and
-#' what are value labels. \code{.apply_labels} is version for working
-#' with default dataset. See also \link{var_lab} and \link{val_lab}.
+#' what are value labels. See also \link{var_lab} and \link{val_lab}.
 #'
 #' @param data data.frame/list 
-#' @param ...  named arguments. Name of argument is a variable name in
-#'   \code{data}. Argument values are variable or value labels. Unnamed
+#' @param ...  named arguments or lists. Name of argument is a variable name in
+#'   the \code{data}. Argument values are variable or value labels. Unnamed
 #'   characters of length 1 are considered as variable labels and named vectors
-#'   are considered as value labels.
+#'   are considered as value labels. List arguments should be named lists and contain
+#'   value and variable labels.
 #'   
 #' @return \code{data} with applied labels
 #' @export
@@ -31,8 +31,23 @@
 #' # 'table' from base R
 #' table(mtcars$vs, mtcars$am)
 #' 
-#' # more sofisticated crosstable
-#' calculate(mtcars, cro(vs, am))
+#' # more sophisticated crosstable
+#' cross_cases(mtcars, vs, am)
+#' 
+#' # the same but with list argument
+#' list_arg = list( vs = "Engine",
+#'                  vs = num_lab("
+#'                              0 V-engine 
+#'                              1 Straight engine
+#'                              "),
+#'                  am = "Transmission",
+#'                  am = num_lab("
+#'                              0 Automatic 
+#'                              1 Manual
+#'                              ")
+#'                  )
+#' 
+#' mtcars = apply_labels(mtcars, list_arg)
 #' 
 apply_labels = function(data, ...){
     UseMethod("apply_labels")
@@ -42,6 +57,7 @@ apply_labels = function(data, ...){
 apply_labels.list = function(data, ...){
     data_names = names(data)
     args = list(...)
+    args = flat_list(args, flat_df = FALSE) # merge list arguments
     names_args = names(args)
     unknowns = setdiff(names_args, data_names)
     if(length(unknowns)){
@@ -80,15 +96,3 @@ apply_labels.data.frame = function(data, ...){
     apply_labels.list(data, ...)
 }
 
-
-
-#' @export
-#' @rdname apply_labels
-.apply_labels = function(...){
-    reference = suppressMessages(default_dataset())
-    data = ref(reference)
-    data = apply_labels(data, ...)
-    ref(reference) = data
-    invisible(data)
-}
-
