@@ -1,11 +1,20 @@
 context("dichotomy.default")
 suppressWarnings(RNGversion("3.5.0"))
 
+
+if(getRversion() < "4.0.0") {
+  MATRIX_CLASS = c("matrix")
+  
+} else {
+  MATRIX_CLASS = c("matrix", "array") 
+}
+
+
 expect_error(as.dichotomy(NULL))
 
 expect_identical(dummy(numeric(0)),
                  structure(numeric(0), .Dim = c(0L, 0L), class = c("dichotomy", 
-                                                                   "matrix")))
+                                                                   MATRIX_CLASS)))
 
 expect_identical(as.dichotomy(numeric(0)),
 structure(list(`NA` = logical(0)), row.names = integer(0), .Names = "NA", class = c("dichotomy", 
@@ -14,7 +23,7 @@ structure(list(`NA` = logical(0)), row.names = integer(0), .Names = "NA", class
 
 expect_identical(dummy(c(NA,NA,NA)),
 structure(c(NA, NA, NA)*1, .Dim = c(3L, 1L), .Dimnames = list(
- NULL, "NA"), class = c("dichotomy", "matrix")))
+ NULL, "NA"), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(as.dichotomy(c(NA,NA,NA)),
 structure(list(`NA` = c(NA, NA, NA)), row.names = c(NA, -3L), .Names = "NA", class = c("dichotomy", 
@@ -24,7 +33,7 @@ structure(list(`NA` = c(NA, NA, NA)), row.names = c(NA, -3L), .Names = "NA", cla
 vec = 1
 
 expect_identical(dummy(vec),
-                 structure(1, .Dim = c(1L, 1L), .Dimnames = list(NULL, "1"), class = c("dichotomy", "matrix")))
+                 structure(1, .Dim = c(1L, 1L), .Dimnames = list(NULL, "1"), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(as.dichotomy(vec),
 structure(list(v1 = structure(1, label = "1", class = c("labelled", 
@@ -35,33 +44,33 @@ structure(list(v1 = structure(1, label = "1", class = c("labelled",
 vec = 1:3
 expect_identical(dummy(vec),
                  structure(c(1, 0, 0, 0, 1, 0, 0, 0, 1), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2", "3")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, presence = 5, absence = -5),
                  structure(c(5, -5, -5, -5, 5, -5, -5, -5, 5), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2", "3")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, presence = "Y", absence = "N"),
                  structure(c("Y", "N", "N", "N", "Y", "N", "N", "N", "Y"), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2", "3")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, presence = FALSE, absence = TRUE),
                  structure(c(FALSE, TRUE, TRUE, TRUE, FALSE, TRUE, TRUE, TRUE, FALSE), 
                            .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2", "3")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy1(vec, presence = 5, absence = -5),
                  structure(c(5, -5, -5, -5, 5, -5), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy1(vec, presence = "Y", absence = "N"),
                  structure(c("Y", "N", "N", "N", "Y", "N"), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy1(vec, presence = FALSE, absence = TRUE),
                  structure(c(FALSE, TRUE, TRUE, TRUE, FALSE, TRUE), 
                            .Dim = c(3L, 2L), .Dimnames = list(
-                               NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+                               NULL, c("1", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(as.dichotomy(vec),
 structure(list(v1 = structure(c(1, 0, 0), label = "1", class = c("labelled", 
@@ -88,7 +97,7 @@ structure(list(v1 = structure(c("Y", "N", "N"), label = "1", class = c("labelled
 vec = c(1:2,NA)
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(as.dichotomy(vec),
 structure(list(v1 = structure(c(1, 0, NA), label = "1", class = c("labelled", 
@@ -99,7 +108,7 @@ structure(list(v1 = structure(c(1, 0, NA), label = "1", class = c("labelled",
 
 expect_identical(dummy(vec,use_na = FALSE),
                  structure(c(1, 0, 0, 0, 1, 0), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(as.dichotomy(vec, use_na = FALSE),
 structure(list(v1 = structure(c(1, 0, 0), label = "1", class = c("labelled", 
@@ -116,11 +125,11 @@ val_lab(vec_mat) = c(a=1,b=2,d=45)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec_mat),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(as.dichotomy(vec), as.dichotomy(vec_mat))
 
@@ -133,12 +142,12 @@ structure(list(v1 = structure(c(1, 0, 0), label = "a", class = c("labelled",
 
 expect_identical(dummy(vec,use_na = FALSE),
                  structure(c(1, 0, 0, 0, 1, 0), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "b","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(as.dichotomy(vec, use_na = FALSE, keep_unused = TRUE),
 structure(list(v1 = structure(c(1, 0, 0), label = "a", class = c("labelled", 
@@ -165,11 +174,11 @@ val_lab(vec) = c(a=1,d=45)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "2","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -178,80 +187,77 @@ val_lab(vec) = c(a=1,d=45)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("Label|a", "Label|2")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a", "Label|2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("Label|a", "Label|2","Label|d")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a", "Label|2","Label|d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 dep = c(1,1,1,2,2,2)
 indep = c(1,1,3,2,2,3)
 var_lab(indep) = "Label"
 val_lab(indep) = c(a=1,b=2,c=3)
-if(FALSE){
-    expect_equal_to_reference(lm(dep ~ dummy(indep)),"rds/lm_dichotomy_default.rds",  update = FALSE)
-    expect_equal_to_reference(lm(dep ~ dummy1(indep)),"rds/lm_dichotomy_default2.rds",  update = FALSE)
-}
+
 
 expect_identical(dummy(indep,keep_values=1),structure(c(1, 1, 0, 0, 0, 0), .Dim = c(6L, 1L), .Dimnames = list(
-    NULL, "Label|a"), class = c("dichotomy", "matrix")))
+    NULL, "Label|a"), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(indep,drop_values=2:3),structure(c(1, 1, 0, 0, 0, 0), .Dim = c(6L, 1L), .Dimnames = list(
-    NULL, "Label|a"), class = c("dichotomy", "matrix")))
+    NULL, "Label|a"), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(indep,keep_values=2:3),structure(c(0, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0, 1), 
                                                      .Dim = c(6L,2L), .Dimnames = list(NULL, c("Label|b", "Label|c")), 
-                                                     class = c("dichotomy","matrix")))
+                                                     class = c("dichotomy",MATRIX_CLASS)))
 
 expect_identical(dummy(indep,drop_values=1),structure(c(0, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0, 1), 
                                                             .Dim = c(6L,2L), .Dimnames = list(NULL, c("Label|b", "Label|c")), 
-                                                            class = c("dichotomy","matrix")))
+                                                            class = c("dichotomy",MATRIX_CLASS)))
 
 
 expect_identical(dummy(indep,keep_labels=c("c")),structure(c(0, 0, 1, 0, 0, 1), .Dim = c(6L, 1L), .Dimnames = list(
-NULL, "Label|c"), class = c("dichotomy", "matrix")))
+NULL, "Label|c"), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(indep,drop_labels=c("a","b")),structure(c(0, 0, 1, 0, 0, 1), .Dim = c(6L, 1L), .Dimnames = list(
-NULL, "Label|c"), class = c("dichotomy", "matrix")))
+NULL, "Label|c"), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(indep,keep_labels=c("a","c")),structure(c(1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1), .Dim = c(6L, 2L), 
 .Dimnames = list(NULL, c("Label|a", "Label|c")), class = c("dichotomy", 
-                                                           "matrix")))
+                                                           MATRIX_CLASS)))
 expect_identical(dummy(indep,drop_labels=c("b")),structure(c(1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1), .Dim = c(6L, 2L), 
        .Dimnames = list(NULL, c("Label|a", "Label|c")), class = c("dichotomy", 
-                                                                  "matrix")))
+                                                                  MATRIX_CLASS)))
 
 
 vec = letters[1:5]
 expect_identical(dummy(vec),structure(c(1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
                                             0, 1, 0, 0, 0, 0, 0, 1), .Dim = c(5L, 5L), .Dimnames = list(NULL, 
-                                                                                                        c("a", "b", "c", "d", "e")), class = c("dichotomy", "matrix"
+                                                                                                        c("a", "b", "c", "d", "e")), class = c("dichotomy", MATRIX_CLASS
                                                                                                         )))
 
 
 vec = as.factor(letters[1:5])
 expect_identical(dummy(vec),structure(c(1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
                            0, 1, 0, 0, 0, 0, 0, 1), .Dim = c(5L, 5L), .Dimnames = list(NULL, 
-                                                                                       c("a", "b", "c", "d", "e")), class = c("dichotomy", "matrix"
+                                                                                       c("a", "b", "c", "d", "e")), class = c("dichotomy", MATRIX_CLASS
                                                                                        )))
 
 expect_identical(dummy(vec,keep_labels=c("d","e")),structure(c(0, 0, 0, 1, 0, 0, 0, 0, 0, 1), .Dim = c(5L, 2L), .Dimnames = list(
-    NULL, c("d", "e")), class = c("dichotomy", "matrix")))
+    NULL, c("d", "e")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec,drop_labels=letters[1:3]),structure(c(0, 0, 0, 1, 0, 0, 0, 0, 0, 1), .Dim = c(5L, 2L), .Dimnames = list(
-    NULL, c("d", "e")), class = c("dichotomy", "matrix")))
+    NULL, c("d", "e")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 context("dichotomy.data.frame")
 vec = data.frame(1)
 
 expect_identical(dummy(vec),
-                 structure(1, .Dim = c(1L, 1L), .Dimnames = list(NULL, "1"), class = c("dichotomy", "matrix")))
+                 structure(1, .Dim = c(1L, 1L), .Dimnames = list(NULL, "1"), class = c("dichotomy", MATRIX_CLASS)))
 vec = data.frame(1:3)
 expect_identical(dummy(vec),
                  structure(c(1, 0, 0, 0, 1, 0, 0, 0, 1), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("1", "2", "3")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2", "3")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 
@@ -259,11 +265,11 @@ expect_identical(dummy(vec),
 vec = data.frame(c(1:2,NA))
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec,use_na = FALSE),
                  structure(c(1, 0, 0, 0, 1, 0), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("1", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("1", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -273,16 +279,16 @@ vec = data.frame(vec)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec,use_na = FALSE),
                  structure(c(1, 0, 0, 0, 1, 0), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "b","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -291,11 +297,11 @@ vec = data.frame(vec)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "2","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -305,11 +311,11 @@ vec = data.frame(vec)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("Label|a", "Label|2")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a", "Label|2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("Label|a", "Label|2","Label|d")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a", "Label|2","Label|d")), class = c("dichotomy", MATRIX_CLASS)))
 
 ########## label on entire dataset
 vec = c(1:2,NA)
@@ -320,16 +326,16 @@ val_lab(vec) = c(a=1,b=2,d=45)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec,use_na = FALSE),
                  structure(c(1, 0, 0, 0, 1, 0), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "b","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -339,11 +345,11 @@ val_lab(vec) = c(a=1,d=45)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "2","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -354,11 +360,11 @@ val_lab(vec) = c(a=1,d=45)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("Label|a", "Label|2")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a", "Label|2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("Label|a", "Label|2","Label|d")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a", "Label|2","Label|d")), class = c("dichotomy", MATRIX_CLASS)))
 
 #############
 
@@ -371,16 +377,16 @@ vec = data.frame(vec,vec)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec,use_na = FALSE),
                  structure(c(1, 0, 0, 0, 1, 0), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "b")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "b","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "b","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -389,11 +395,11 @@ vec = data.frame(vec,vec,vec)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "2","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -403,11 +409,11 @@ vec = data.frame(vec,vec,vec)
 
 expect_identical(dummy(vec),
                  structure(c(1, 0, NA, 0, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("Label|a", "Label|2")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a", "Label|2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, NA, 0, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("Label|a", "Label|2","Label|d")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a", "Label|2","Label|d")), class = c("dichotomy", MATRIX_CLASS)))
 
 #############
 
@@ -418,16 +424,16 @@ vec = data.frame(vec,3:5)
 
 expect_identical(dummy(vec),
 structure(c(1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1), .Dim = c(3L, 
-5L), .Dimnames = list(NULL, c("a", "b", "3", "4", "5")), class = c("dichotomy",  "matrix")))
+5L), .Dimnames = list(NULL, c("a", "b", "3", "4", "5")), class = c("dichotomy",  MATRIX_CLASS)))
 
 expect_identical(dummy(vec,use_na = FALSE),
                  structure(c(1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1), .Dim = c(3L, 
-    5L), .Dimnames = list(NULL, c("a", "b", "3", "4", "5")), class = c("dichotomy", "matrix"))) 
+    5L), .Dimnames = list(NULL, c("a", "b", "3", "4", "5")), class = c("dichotomy", MATRIX_CLASS))) 
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 
                              0), .Dim = c(3L, 6L), .Dimnames = list(NULL, c("a", "b", "3", 
-                "4", "5", "d")), class = c("dichotomy", "matrix")))
+                "4", "5", "d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -436,11 +442,11 @@ vec = data.frame(vec,c(2,1,NA))
 
 expect_identical(dummy(vec),
                  structure(c(1, 1, NA, 1, 1, NA), .Dim = c(3L, 2L), .Dimnames = list(
-                     NULL, c("a", "2")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE),
                  structure(c(1, 1, NA, 1, 1, NA,0,0,NA), .Dim = c(3L, 3L), .Dimnames = list(
-                     NULL, c("a", "2","d")), class = c("dichotomy", "matrix")))
+                     NULL, c("a", "2","d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 vec = c(1:2,NA)
@@ -450,17 +456,17 @@ vec = data.frame(vec,vec,vec)
 
 expect_identical(dummy(vec,keep_labels="a"),
                  structure(c(1, 0, NA), .Dim = c(3L, 1L), .Dimnames = list(
-                     NULL, c("Label|a")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec,drop_values =2),
                  structure(c(1, 0, NA), .Dim = c(3L, 1L), .Dimnames = list(
-                     NULL, c("Label|a")), class = c("dichotomy", "matrix")))
+                     NULL, c("Label|a")), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy(vec, keep_unused = TRUE,keep_values=c(2:7,45)),
                  structure(c(0, 1, NA, 0, 0, NA, 0, 0, NA, 0, 0, NA, 0, 0, NA, 
                              0, 0, NA, 0, 0, NA), .Dim = c(3L, 7L), .Dimnames = list(NULL, 
                              c("Label|2", "Label|3", "Label|4", "Label|5", "Label|6", 
-                            "Label|7", "Label|d")), class = c("dichotomy", "matrix")))
+                            "Label|7", "Label|d")), class = c("dichotomy", MATRIX_CLASS)))
 
 
 
@@ -468,7 +474,15 @@ expect_error(dummy(vec, keep_unused = TRUE,keep_labels="unknown label"))
 
 set.seed(123)
 brands = as.data.frame(t(replicate(20,sample(c(1:5,NA),4,replace = FALSE))))
-expect_equal_to_reference(dummy(brands[,1]),"rds/brands.rds",  update = FALSE)
+expect_identical(dummy(brands[,1]), structure(c(0, NA, 0, 0, 0, NA, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 
+0, 0, 0, 0, 1, NA, 0, 0, 1, NA, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 
+0, 0, 0, 0, 0, NA, 0, 0, 0, NA, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 1, 0, NA, 1, 0, 0, NA, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
+0, 0, 0, 0, 0, NA, 0, 1, 0, NA, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0, 
+1, 1, 1, 0), .Dim = c(20L, 5L), .Dimnames = list(NULL, c("1", 
+                                                       "2", "3", "4", "5")), 
+class = c("dichotomy", MATRIX_CLASS
+)))
 var_lab(brands) = "Used brands"
 val_lab(brands) = make_labels("
                               1 Brand A
@@ -521,7 +535,7 @@ expect_identical(dummy(dich),
 structure(c(NA, NA, NA)*1, 
 .Dim = c(3L, 1L), 
 .Dimnames = list(NULL, 
-"NA"), class = c("dichotomy", "matrix")))
+"NA"), class = c("dichotomy", MATRIX_CLASS)))
 
 
 expect_identical(as.dichotomy(NA), 
@@ -534,13 +548,13 @@ expect_identical(dummy(NA),
                  structure(NA*1, 
                            .Dim = c(1L, 1L), 
                            .Dimnames = list(NULL, 
-"NA"), class = c("dichotomy", "matrix")))
+"NA"), class = c("dichotomy", MATRIX_CLASS)))
 
 expect_identical(dummy1(NA), 
 structure(NA*1, 
 .Dim = c(1L, 1L), 
 .Dimnames = list(NULL, 
-"NA"), class = c("dichotomy", "matrix")))
+"NA"), class = c("dichotomy", MATRIX_CLASS)))
 
 
 expect_identical(as.dichotomy(dich[FALSE, FALSE, drop = FALSE]),
